@@ -9,6 +9,7 @@ urlpatterns = patterns('demoproject.views',
     url(r'^$', 'home', name='home'),
     url(r'^piechart/', 'demo_piechart', name='demo_piechart'),
     url(r'^linechart/', 'demo_linechart', name='demo_linechart'),
+    url(r'^linechart_without_date/', 'demo_linechart_without_date', name='demo_linechart_without_date'),
     url(r'^linewithfocuschart/', 'demo_linewithfocuschart', name='demo_linewithfocuschart'),
     url(r'^multibarchart/', 'demo_multibarchart', name='demo_multibarchart'),
     url(r'^stackedareachart/', 'demo_stackedareachart', name='demo_stackedareachart'),
@@ -17,6 +18,7 @@ urlpatterns = patterns('demoproject.views',
     url(r'^cumulativelinechart/', 'demo_cumulativelinechart', name='demo_cumulativelinechart'),
     url(r'^discretebarchart/', 'demo_discretebarchart', name='demo_discretebarchart'),
     url(r'^scatterchart/', 'demo_scatterchart', name='demo_scatterchart'),
+    url(r'^linechart_with_ampm/', 'demo_linechart_with_ampm', name='demo_linechart_with_ampm'),
     # url(r'^demoproject/', include('demoproject.foo.urls')),
 
     # Uncomment the admin/doc line below to enable admin documentation:
